@@ -277,6 +277,8 @@ class Ppos(Module):
             raw_data_dict["RestrictingPlan"] = int(raw_data_dict["RestrictingPlan"], 16)
             raw_data_dict["RestrictingPlanHes"] = int(raw_data_dict["RestrictingPlanHes"], 16)
             raw_data_dict["DelegateRewardTotal"] = int(raw_data_dict["DelegateRewardTotal"], 16)
+            raw_data_dict["DelegateTotal"] = int(raw_data_dict["DelegateTotal"], 16)
+            raw_data_dict["DelegateTotalHes"] = int(raw_data_dict["DelegateTotalHes"], 16)
             receive["Ret"] = raw_data_dict
         except:...
         return receive
@@ -409,12 +411,11 @@ class Ppos(Module):
         receive = json.loads(str(raw_data, encoding="ISO-8859-1"))
         try:
             raw_data_dict = receive["Ret"]
-            decimal_10 = []
-            if raw_data_dict["reward"]:
-                for i in raw_data_dict["reward"]:
-                    decimal_10.append(int(i, 16))
-                raw_data_dict["reward"] = decimal_10
-            receive["Ret"] = raw_data_dict
+            result = []
+            for d in raw_data_dict:
+                d["reward"] = int(d["reward"], 16)
+                result.append(d)
+            receive["Ret"] = result
         except:...
         return receive
 
